# Linux

This guide will help one to proceed with BlocksNet on Linux. At first one have to update system packages:

```bash
sudo apt update && sudo apt upgrade -y
```

```{toctree}
:maxdepth: 1

1_git
2_python
3_venv
4_blocksnet
```
